# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = [
    'account_id',
    'admin_api_key',
    'api_key',
    'api_url',
    'cacert_file',
    'infrastructure_api_url',
    'insecure_skip_verify',
    'insights_insert_key',
    'insights_insert_url',
    'insights_query_url',
    'nerdgraph_api_url',
    'region',
    'synthetics_api_url',
]

__config__ = pulumi.Config('newrelic')

account_id = __config__.get('accountId') or _utilities.get_env_int('NEW_RELIC_ACCOUNT_ID')

admin_api_key = __config__.get('adminApiKey')

api_key = __config__.get('apiKey')

api_url = __config__.get('apiUrl')

cacert_file = __config__.get('cacertFile')

infrastructure_api_url = __config__.get('infrastructureApiUrl')

insecure_skip_verify = __config__.get('insecureSkipVerify')

insights_insert_key = __config__.get('insightsInsertKey')

insights_insert_url = __config__.get('insightsInsertUrl')

insights_query_url = __config__.get('insightsQueryUrl')

nerdgraph_api_url = __config__.get('nerdgraphApiUrl')

region = __config__.get('region') or (_utilities.get_env('NEW_RELIC_REGION') or 'US')
"""
The data center for which your New Relic account is configured. Only one region per provider block is permitted.
"""

synthetics_api_url = __config__.get('syntheticsApiUrl')

